package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcAqyh;
import com.ruoyi.tcZz.service.ITcAqyhService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 安全隐患 tc_aqyhController
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/aqyh")
public class TcAqyhController extends BaseController
{
    @Autowired
    private ITcAqyhService tcAqyhService;

    /**
     * 查询安全隐患 tc_aqyh列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:aqyh:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcAqyh tcAqyh)
    {
        startPage();
        List<TcAqyh> list = tcAqyhService.selectTcAqyhList(tcAqyh);
        return getDataTable(list);
    }

    /**
     * 导出安全隐患 tc_aqyh列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:aqyh:export')")
    @Log(title = "安全隐患 tc_aqyh", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcAqyh tcAqyh)
    {
        List<TcAqyh> list = tcAqyhService.selectTcAqyhList(tcAqyh);
        ExcelUtil<TcAqyh> util = new ExcelUtil<TcAqyh>(TcAqyh.class);
        util.exportExcel(response, list, "安全隐患 tc_aqyh数据");
    }

    /**
     * 获取安全隐患 tc_aqyh详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:aqyh:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcAqyhService.selectTcAqyhById(id));
    }

    /**
     * 新增安全隐患 tc_aqyh
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:aqyh:add')")
    @Log(title = "安全隐患 tc_aqyh", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcAqyh tcAqyh)
    {
        return toAjax(tcAqyhService.insertTcAqyh(tcAqyh));
    }

    /**
     * 修改安全隐患 tc_aqyh
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:aqyh:edit')")
    @Log(title = "安全隐患 tc_aqyh", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcAqyh tcAqyh)
    {
        return toAjax(tcAqyhService.updateTcAqyh(tcAqyh));
    }

    /**
     * 删除安全隐患 tc_aqyh
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:aqyh:remove')")
    @Log(title = "安全隐患 tc_aqyh", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcAqyhService.deleteTcAqyhByIds(ids));
    }
}
