package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcBmtb;
import com.ruoyi.tcZz.service.ITcBmtbService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 部门通报Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/bmtb")
public class TcBmtbController extends BaseController
{
    @Autowired
    private ITcBmtbService tcBmtbService;

    /**
     * 查询部门通报列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:bmtb:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcBmtb tcBmtb)
    {
        startPage();
        List<TcBmtb> list = tcBmtbService.selectTcBmtbList(tcBmtb);
        return getDataTable(list);
    }

    /**
     * 导出部门通报列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:bmtb:export')")
    @Log(title = "部门通报", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcBmtb tcBmtb)
    {
        List<TcBmtb> list = tcBmtbService.selectTcBmtbList(tcBmtb);
        ExcelUtil<TcBmtb> util = new ExcelUtil<TcBmtb>(TcBmtb.class);
        util.exportExcel(response, list, "部门通报数据");
    }

    /**
     * 获取部门通报详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:bmtb:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcBmtbService.selectTcBmtbById(id));
    }

    /**
     * 新增部门通报
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:bmtb:add')")
    @Log(title = "部门通报", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcBmtb tcBmtb)
    {
        return toAjax(tcBmtbService.insertTcBmtb(tcBmtb));
    }

    /**
     * 修改部门通报
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:bmtb:edit')")
    @Log(title = "部门通报", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcBmtb tcBmtb)
    {
        return toAjax(tcBmtbService.updateTcBmtb(tcBmtb));
    }

    /**
     * 删除部门通报
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:bmtb:remove')")
    @Log(title = "部门通报", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcBmtbService.deleteTcBmtbByIds(ids));
    }
}
