package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcCy;
import com.ruoyi.tcZz.service.ITcCyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 词云Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@RequestMapping("/tcZz/netWorkYq/cy")
public class TcCyController extends BaseController
{
    @Autowired
    private ITcCyService tcCyService;

    /**
     * 查询词云列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:cy:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcCy tcCy)
    {
        startPage();
        List<TcCy> list = tcCyService.selectTcCyList(tcCy);
        return getDataTable(list);
    }

    /**
     * 导出词云列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:cy:export')")
    @Log(title = "词云", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcCy tcCy)
    {
        List<TcCy> list = tcCyService.selectTcCyList(tcCy);
        ExcelUtil<TcCy> util = new ExcelUtil<TcCy>(TcCy.class);
        util.exportExcel(response, list, "词云数据");
    }

    /**
     * 获取词云详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:cy:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcCyService.selectTcCyById(id));
    }

    /**
     * 新增词云
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:cy:add')")
    @Log(title = "词云", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcCy tcCy)
    {
        return toAjax(tcCyService.insertTcCy(tcCy));
    }

    /**
     * 修改词云
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:cy:edit')")
    @Log(title = "词云", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcCy tcCy)
    {
        return toAjax(tcCyService.updateTcCy(tcCy));
    }

    /**
     * 删除词云
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:cy:remove')")
    @Log(title = "词云", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcCyService.deleteTcCyByIds(ids));
    }
}
