package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcDbdw;
import com.ruoyi.tcZz.service.ITcDbdwService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 等保单位Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/dbdw")
public class TcDbdwController extends BaseController
{
    @Autowired
    private ITcDbdwService tcDbdwService;

    /**
     * 查询等保单位列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:dbdw:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcDbdw tcDbdw)
    {
        startPage();
        List<TcDbdw> list = tcDbdwService.selectTcDbdwList(tcDbdw);
        return getDataTable(list);
    }

    /**
     * 导出等保单位列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:dbdw:export')")
    @Log(title = "等保单位", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcDbdw tcDbdw)
    {
        List<TcDbdw> list = tcDbdwService.selectTcDbdwList(tcDbdw);
        ExcelUtil<TcDbdw> util = new ExcelUtil<TcDbdw>(TcDbdw.class);
        util.exportExcel(response, list, "等保单位数据");
    }

    /**
     * 获取等保单位详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:dbdw:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcDbdwService.selectTcDbdwById(id));
    }

    /**
     * 新增等保单位
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:dbdw:add')")
    @Log(title = "等保单位", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcDbdw tcDbdw)
    {
        return toAjax(tcDbdwService.insertTcDbdw(tcDbdw));
    }

    /**
     * 修改等保单位
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:dbdw:edit')")
    @Log(title = "等保单位", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcDbdw tcDbdw)
    {
        return toAjax(tcDbdwService.updateTcDbdw(tcDbdw));
    }

    /**
     * 删除等保单位
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:dbdw:remove')")
    @Log(title = "等保单位", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcDbdwService.deleteTcDbdwByIds(ids));
    }
}
