package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcDbxt;
import com.ruoyi.tcZz.service.ITcDbxtService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 等保系统Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/dbxt")
public class TcDbxtController extends BaseController
{
    @Autowired
    private ITcDbxtService tcDbxtService;

    /**
     * 查询等保系统列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:dbxt:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcDbxt tcDbxt)
    {
        startPage();
        List<TcDbxt> list = tcDbxtService.selectTcDbxtList(tcDbxt);
        return getDataTable(list);
    }

    /**
     * 导出等保系统列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:dbxt:export')")
    @Log(title = "等保系统", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcDbxt tcDbxt)
    {
        List<TcDbxt> list = tcDbxtService.selectTcDbxtList(tcDbxt);
        ExcelUtil<TcDbxt> util = new ExcelUtil<TcDbxt>(TcDbxt.class);
        util.exportExcel(response, list, "等保系统数据");
    }

    /**
     * 获取等保系统详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:dbxt:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcDbxtService.selectTcDbxtById(id));
    }

    /**
     * 新增等保系统
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:dbxt:add')")
    @Log(title = "等保系统", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcDbxt tcDbxt)
    {
        return toAjax(tcDbxtService.insertTcDbxt(tcDbxt));
    }

    /**
     * 修改等保系统
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:dbxt:edit')")
    @Log(title = "等保系统", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcDbxt tcDbxt)
    {
        return toAjax(tcDbxtService.updateTcDbxt(tcDbxt));
    }

    /**
     * 删除等保系统
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:dbxt:remove')")
    @Log(title = "等保系统", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcDbxtService.deleteTcDbxtByIds(ids));
    }
}
