package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcDtsx;
import com.ruoyi.tcZz.service.ITcDtsxService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 动态筛选Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/netWorkYq/dtsx")
public class TcDtsxController extends BaseController
{
    @Autowired
    private ITcDtsxService tcDtsxService;

    /**
     * 查询动态筛选列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:dtsx:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcDtsx tcDtsx)
    {
        startPage();
        List<TcDtsx> list = tcDtsxService.selectTcDtsxList(tcDtsx);
        return getDataTable(list);
    }

    /**
     * 导出动态筛选列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:dtsx:export')")
    @Log(title = "动态筛选", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcDtsx tcDtsx)
    {
        List<TcDtsx> list = tcDtsxService.selectTcDtsxList(tcDtsx);
        ExcelUtil<TcDtsx> util = new ExcelUtil<TcDtsx>(TcDtsx.class);
        util.exportExcel(response, list, "动态筛选数据");
    }

    /**
     * 获取动态筛选详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:dtsx:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcDtsxService.selectTcDtsxById(id));
    }

    /**
     * 新增动态筛选
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:dtsx:add')")
    @Log(title = "动态筛选", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcDtsx tcDtsx)
    {
        return toAjax(tcDtsxService.insertTcDtsx(tcDtsx));
    }

    /**
     * 修改动态筛选
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:dtsx:edit')")
    @Log(title = "动态筛选", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcDtsx tcDtsx)
    {
        return toAjax(tcDtsxService.updateTcDtsx(tcDtsx));
    }

    /**
     * 删除动态筛选
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:dtsx:remove')")
    @Log(title = "动态筛选", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcDtsxService.deleteTcDtsxByIds(ids));
    }
}
