package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcFbqk;
import com.ruoyi.tcZz.service.ITcFbqkService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 分布情况 tc_fbqkController
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/fbqk")
public class TcFbqkController extends BaseController
{
    @Autowired
    private ITcFbqkService tcFbqkService;

    /**
     * 查询分布情况 tc_fbqk列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:fbqk:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcFbqk tcFbqk)
    {
        startPage();
        List<TcFbqk> list = tcFbqkService.selectTcFbqkList(tcFbqk);
        return getDataTable(list);
    }

    /**
     * 导出分布情况 tc_fbqk列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:fbqk:export')")
    @Log(title = "分布情况 tc_fbqk", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcFbqk tcFbqk)
    {
        List<TcFbqk> list = tcFbqkService.selectTcFbqkList(tcFbqk);
        ExcelUtil<TcFbqk> util = new ExcelUtil<TcFbqk>(TcFbqk.class);
        util.exportExcel(response, list, "分布情况 tc_fbqk数据");
    }

    /**
     * 获取分布情况 tc_fbqk详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:fbqk:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcFbqkService.selectTcFbqkById(id));
    }

    /**
     * 新增分布情况 tc_fbqk
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:fbqk:add')")
    @Log(title = "分布情况 tc_fbqk", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcFbqk tcFbqk)
    {
        return toAjax(tcFbqkService.insertTcFbqk(tcFbqk));
    }

    /**
     * 修改分布情况 tc_fbqk
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:fbqk:edit')")
    @Log(title = "分布情况 tc_fbqk", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcFbqk tcFbqk)
    {
        return toAjax(tcFbqkService.updateTcFbqk(tcFbqk));
    }

    /**
     * 删除分布情况 tc_fbqk
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:fbqk:remove')")
    @Log(title = "分布情况 tc_fbqk", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcFbqkService.deleteTcFbqkByIds(ids));
    }
}
