package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcGzdt;
import com.ruoyi.tcZz.service.ITcGzdtService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 工作动态Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@RequestMapping("/tcZz/netManage/gzdt")
public class TcGzdtController extends BaseController
{
    @Autowired
    private ITcGzdtService tcGzdtService;

    /**
     * 查询工作动态列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:gzdt:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcGzdt tcGzdt)
    {
        startPage();
        List<TcGzdt> list = tcGzdtService.selectTcGzdtList(tcGzdt);
        return getDataTable(list);
    }

    /**
     * 导出工作动态列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:gzdt:export')")
    @Log(title = "工作动态", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcGzdt tcGzdt)
    {
        List<TcGzdt> list = tcGzdtService.selectTcGzdtList(tcGzdt);
        ExcelUtil<TcGzdt> util = new ExcelUtil<TcGzdt>(TcGzdt.class);
        util.exportExcel(response, list, "工作动态数据");
    }

    /**
     * 获取工作动态详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:gzdt:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcGzdtService.selectTcGzdtById(id));
    }

    /**
     * 新增工作动态
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:gzdt:add')")
    @Log(title = "工作动态", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcGzdt tcGzdt)
    {
        return toAjax(tcGzdtService.insertTcGzdt(tcGzdt));
    }

    /**
     * 修改工作动态
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:gzdt:edit')")
    @Log(title = "工作动态", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcGzdt tcGzdt)
    {
        return toAjax(tcGzdtService.updateTcGzdt(tcGzdt));
    }

    /**
     * 删除工作动态
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:gzdt:remove')")
    @Log(title = "工作动态", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcGzdtService.deleteTcGzdtByIds(ids));
    }
}
