package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcJgdw;
import com.ruoyi.tcZz.service.ITcJgdwService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 监管单位Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/jgdw")
public class TcJgdwController extends BaseController
{
    @Autowired
    private ITcJgdwService tcJgdwService;

    /**
     * 查询监管单位列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:jgdw:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcJgdw tcJgdw)
    {
        startPage();
        List<TcJgdw> list = tcJgdwService.selectTcJgdwList(tcJgdw);
        return getDataTable(list);
    }

    /**
     * 导出监管单位列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:jgdw:export')")
    @Log(title = "监管单位", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcJgdw tcJgdw)
    {
        List<TcJgdw> list = tcJgdwService.selectTcJgdwList(tcJgdw);
        ExcelUtil<TcJgdw> util = new ExcelUtil<TcJgdw>(TcJgdw.class);
        util.exportExcel(response, list, "监管单位数据");
    }

    /**
     * 获取监管单位详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:jgdw:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcJgdwService.selectTcJgdwById(id));
    }

    /**
     * 新增监管单位
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:jgdw:add')")
    @Log(title = "监管单位", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcJgdw tcJgdw)
    {
        return toAjax(tcJgdwService.insertTcJgdw(tcJgdw));
    }

    /**
     * 修改监管单位
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:jgdw:edit')")
    @Log(title = "监管单位", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcJgdw tcJgdw)
    {
        return toAjax(tcJgdwService.updateTcJgdw(tcJgdw));
    }

    /**
     * 删除监管单位
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:jgdw:remove')")
    @Log(title = "监管单位", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcJgdwService.deleteTcJgdwByIds(ids));
    }
}
