package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcMap;
import com.ruoyi.tcZz.service.ITcMapService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 地图统计Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/map")
public class TcMapController extends BaseController
{
    @Autowired
    private ITcMapService tcMapService;

    /**
     * 查询地图统计列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:map:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcMap tcMap)
    {
        startPage();
        List<TcMap> list = tcMapService.selectTcMapList(tcMap);
        return getDataTable(list);
    }

    /**
     * 导出地图统计列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:map:export')")
    @Log(title = "地图统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcMap tcMap)
    {
        List<TcMap> list = tcMapService.selectTcMapList(tcMap);
        ExcelUtil<TcMap> util = new ExcelUtil<TcMap>(TcMap.class);
        util.exportExcel(response, list, "地图统计数据");
    }

    /**
     * 获取地图统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:map:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcMapService.selectTcMapById(id));
    }

    /**
     * 新增地图统计
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:map:add')")
    @Log(title = "地图统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcMap tcMap)
    {
        return toAjax(tcMapService.insertTcMap(tcMap));
    }

    /**
     * 修改地图统计
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:map:edit')")
    @Log(title = "地图统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcMap tcMap)
    {
        return toAjax(tcMapService.updateTcMap(tcMap));
    }

    /**
     * 删除地图统计
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:map:remove')")
    @Log(title = "地图统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcMapService.deleteTcMapByIds(ids));
    }
}
