package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcMtlx;
import com.ruoyi.tcZz.service.ITcMtlxService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 媒体类型Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/netWorkYq/mtlx")
public class TcMtlxController extends BaseController
{
    @Autowired
    private ITcMtlxService tcMtlxService;

    /**
     * 查询媒体类型列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:mtlx:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcMtlx tcMtlx)
    {
        startPage();
        List<TcMtlx> list = tcMtlxService.selectTcMtlxList(tcMtlx);
        return getDataTable(list);
    }

    /**
     * 导出媒体类型列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:mtlx:export')")
    @Log(title = "媒体类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcMtlx tcMtlx)
    {
        List<TcMtlx> list = tcMtlxService.selectTcMtlxList(tcMtlx);
        ExcelUtil<TcMtlx> util = new ExcelUtil<TcMtlx>(TcMtlx.class);
        util.exportExcel(response, list, "媒体类型数据");
    }

    /**
     * 获取媒体类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:mtlx:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcMtlxService.selectTcMtlxById(id));
    }

    /**
     * 新增媒体类型
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:mtlx:add')")
    @Log(title = "媒体类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcMtlx tcMtlx)
    {
        return toAjax(tcMtlxService.insertTcMtlx(tcMtlx));
    }

    /**
     * 修改媒体类型
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:mtlx:edit')")
    @Log(title = "媒体类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcMtlx tcMtlx)
    {
        return toAjax(tcMtlxService.updateTcMtlx(tcMtlx));
    }

    /**
     * 删除媒体类型
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:mtlx:remove')")
    @Log(title = "媒体类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcMtlxService.deleteTcMtlxByIds(ids));
    }
}
