package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcSdtb;
import com.ruoyi.tcZz.service.ITcSdtbService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 属地通报Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/sdtb")
public class TcSdtbController extends BaseController
{
    @Autowired
    private ITcSdtbService tcSdtbService;

    /**
     * 查询属地通报列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:sdtb:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcSdtb tcSdtb)
    {
        startPage();
        List<TcSdtb> list = tcSdtbService.selectTcSdtbList(tcSdtb);
        return getDataTable(list);
    }

    /**
     * 导出属地通报列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:sdtb:export')")
    @Log(title = "属地通报", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcSdtb tcSdtb)
    {
        List<TcSdtb> list = tcSdtbService.selectTcSdtbList(tcSdtb);
        ExcelUtil<TcSdtb> util = new ExcelUtil<TcSdtb>(TcSdtb.class);
        util.exportExcel(response, list, "属地通报数据");
    }

    /**
     * 获取属地通报详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:sdtb:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcSdtbService.selectTcSdtbById(id));
    }

    /**
     * 新增属地通报
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:sdtb:add')")
    @Log(title = "属地通报", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcSdtb tcSdtb)
    {
        return toAjax(tcSdtbService.insertTcSdtb(tcSdtb));
    }

    /**
     * 修改属地通报
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:sdtb:edit')")
    @Log(title = "属地通报", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcSdtb tcSdtb)
    {
        return toAjax(tcSdtbService.updateTcSdtb(tcSdtb));
    }

    /**
     * 删除属地通报
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:sdtb:remove')")
    @Log(title = "属地通报", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcSdtbService.deleteTcSdtbByIds(ids));
    }
}
