package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcSgjipTop5;
import com.ruoyi.tcZz.service.ITcSgjipTop5Service;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 受攻击IPTOP5Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/top5")
public class TcSgjipTop5Controller extends BaseController
{
    @Autowired
    private ITcSgjipTop5Service tcSgjipTop5Service;

    /**
     * 查询受攻击IPTOP5列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:top5:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcSgjipTop5 tcSgjipTop5)
    {
        startPage();
        List<TcSgjipTop5> list = tcSgjipTop5Service.selectTcSgjipTop5List(tcSgjipTop5);
        return getDataTable(list);
    }

    /**
     * 导出受攻击IPTOP5列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:top5:export')")
    @Log(title = "受攻击IPTOP5", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcSgjipTop5 tcSgjipTop5)
    {
        List<TcSgjipTop5> list = tcSgjipTop5Service.selectTcSgjipTop5List(tcSgjipTop5);
        ExcelUtil<TcSgjipTop5> util = new ExcelUtil<TcSgjipTop5>(TcSgjipTop5.class);
        util.exportExcel(response, list, "受攻击IPTOP5数据");
    }

    /**
     * 获取受攻击IPTOP5详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:top5:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcSgjipTop5Service.selectTcSgjipTop5ById(id));
    }

    /**
     * 新增受攻击IPTOP5
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:top5:add')")
    @Log(title = "受攻击IPTOP5", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcSgjipTop5 tcSgjipTop5)
    {
        return toAjax(tcSgjipTop5Service.insertTcSgjipTop5(tcSgjipTop5));
    }

    /**
     * 修改受攻击IPTOP5
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:top5:edit')")
    @Log(title = "受攻击IPTOP5", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcSgjipTop5 tcSgjipTop5)
    {
        return toAjax(tcSgjipTop5Service.updateTcSgjipTop5(tcSgjipTop5));
    }

    /**
     * 删除受攻击IPTOP5
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:top5:remove')")
    @Log(title = "受攻击IPTOP5", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcSgjipTop5Service.deleteTcSgjipTop5ByIds(ids));
    }
}
