package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcSslx;
import com.ruoyi.tcZz.service.ITcSslxService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 涉事类型Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/netWorkYq/sslx")
public class TcSslxController extends BaseController
{
    @Autowired
    private ITcSslxService tcSslxService;

    /**
     * 查询涉事类型列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:sslx:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcSslx tcSslx)
    {
        startPage();
        List<TcSslx> list = tcSslxService.selectTcSslxList(tcSslx);
        return getDataTable(list);
    }

    /**
     * 导出涉事类型列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:sslx:export')")
    @Log(title = "涉事类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcSslx tcSslx)
    {
        List<TcSslx> list = tcSslxService.selectTcSslxList(tcSslx);
        ExcelUtil<TcSslx> util = new ExcelUtil<TcSslx>(TcSslx.class);
        util.exportExcel(response, list, "涉事类型数据");
    }

    /**
     * 获取涉事类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:sslx:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcSslxService.selectTcSslxById(id));
    }

    /**
     * 新增涉事类型
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:sslx:add')")
    @Log(title = "涉事类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcSslx tcSslx)
    {
        return toAjax(tcSslxService.insertTcSslx(tcSslx));
    }

    /**
     * 修改涉事类型
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:sslx:edit')")
    @Log(title = "涉事类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcSslx tcSslx)
    {
        return toAjax(tcSslxService.updateTcSslx(tcSslx));
    }

    /**
     * 删除涉事类型
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:sslx:remove')")
    @Log(title = "涉事类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcSslxService.deleteTcSslxByIds(ids));
    }
}
