package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcTbcz;
import com.ruoyi.tcZz.service.ITcTbczService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 通报处置Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/tbcz")
public class TcTbczController extends BaseController
{
    @Autowired
    private ITcTbczService tcTbczService;

    /**
     * 查询通报处置列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:tbcz:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcTbcz tcTbcz)
    {
        startPage();
        List<TcTbcz> list = tcTbczService.selectTcTbczList(tcTbcz);
        return getDataTable(list);
    }

    /**
     * 导出通报处置列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:tbcz:export')")
    @Log(title = "通报处置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcTbcz tcTbcz)
    {
        List<TcTbcz> list = tcTbczService.selectTcTbczList(tcTbcz);
        ExcelUtil<TcTbcz> util = new ExcelUtil<TcTbcz>(TcTbcz.class);
        util.exportExcel(response, list, "通报处置数据");
    }

    /**
     * 获取通报处置详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:tbcz:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcTbczService.selectTcTbczById(id));
    }

    /**
     * 新增通报处置
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:tbcz:add')")
    @Log(title = "通报处置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcTbcz tcTbcz)
    {
        return toAjax(tcTbczService.insertTcTbcz(tcTbcz));
    }

    /**
     * 修改通报处置
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:tbcz:edit')")
    @Log(title = "通报处置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcTbcz tcTbcz)
    {
        return toAjax(tcTbczService.updateTcTbcz(tcTbcz));
    }

    /**
     * 删除通报处置
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:tbcz:remove')")
    @Log(title = "通报处置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcTbczService.deleteTcTbczByIds(ids));
    }
}
