package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcTbwc;
import com.ruoyi.tcZz.service.ITcTbwcService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 通报完成情况Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/tbwc")
public class TcTbwcController extends BaseController
{
    @Autowired
    private ITcTbwcService tcTbwcService;

    /**
     * 查询通报完成情况列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:tbwc:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcTbwc tcTbwc)
    {
        startPage();
        List<TcTbwc> list = tcTbwcService.selectTcTbwcList(tcTbwc);
        return getDataTable(list);
    }

    /**
     * 导出通报完成情况列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:tbwc:export')")
    @Log(title = "通报完成情况", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcTbwc tcTbwc)
    {
        List<TcTbwc> list = tcTbwcService.selectTcTbwcList(tcTbwc);
        ExcelUtil<TcTbwc> util = new ExcelUtil<TcTbwc>(TcTbwc.class);
        util.exportExcel(response, list, "通报完成情况数据");
    }

    /**
     * 获取通报完成情况详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:tbwc:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcTbwcService.selectTcTbwcById(id));
    }

    /**
     * 新增通报完成情况
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:tbwc:add')")
    @Log(title = "通报完成情况", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcTbwc tcTbwc)
    {
        return toAjax(tcTbwcService.insertTcTbwc(tcTbwc));
    }

    /**
     * 修改通报完成情况
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:tbwc:edit')")
    @Log(title = "通报完成情况", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcTbwc tcTbwc)
    {
        return toAjax(tcTbwcService.updateTcTbwc(tcTbwc));
    }

    /**
     * 删除通报完成情况
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:tbwc:remove')")
    @Log(title = "通报完成情况", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcTbwcService.deleteTcTbwcByIds(ids));
    }
}
