package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.service.ITcWljgtjService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 网络监测统计Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/wljgtj")
public class TcWljgtjController extends BaseController
{
    @Autowired
    private ITcWljgtjService tcWljgtjService;

    /**
     * 查询网络监测统计列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:wljgtj:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcWljgtj tcWljgtj)
    {
        startPage();
        List<TcWljgtj> list = tcWljgtjService.selectTcWljgtjList(tcWljgtj);
        return getDataTable(list);
    }

    /**
     * 导出网络监测统计列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:wljgtj:export')")
    @Log(title = "网络监测统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWljgtj tcWljgtj)
    {
        List<TcWljgtj> list = tcWljgtjService.selectTcWljgtjList(tcWljgtj);
        ExcelUtil<TcWljgtj> util = new ExcelUtil<TcWljgtj>(TcWljgtj.class);
        util.exportExcel(response, list, "网络监测统计数据");
    }

    /**
     * 获取网络监测统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:wljgtj:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcWljgtjService.selectTcWljgtjById(id));
    }

    /**
     * 新增网络监测统计
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:wljgtj:add')")
    @Log(title = "网络监测统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcWljgtj tcWljgtj)
    {
        return toAjax(tcWljgtjService.insertTcWljgtj(tcWljgtj));
    }

    /**
     * 修改网络监测统计
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:wljgtj:edit')")
    @Log(title = "网络监测统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcWljgtj tcWljgtj)
    {
        return toAjax(tcWljgtjService.updateTcWljgtj(tcWljgtj));
    }

    /**
     * 删除网络监测统计
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:wljgtj:remove')")
    @Log(title = "网络监测统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcWljgtjService.deleteTcWljgtjByIds(ids));
    }
}
