package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcYqyj;
import com.ruoyi.tcZz.service.ITcYqyjService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 舆情预警Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/netWorkYq/yqyj")
public class TcYqyjController extends BaseController
{
    @Autowired
    private ITcYqyjService tcYqyjService;

    /**
     * 查询舆情预警列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqyj:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcYqyj tcYqyj)
    {
        startPage();
        List<TcYqyj> list = tcYqyjService.selectTcYqyjList(tcYqyj);
        return getDataTable(list);
    }

    /**
     * 导出舆情预警列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqyj:export')")
    @Log(title = "舆情预警", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcYqyj tcYqyj)
    {
        List<TcYqyj> list = tcYqyjService.selectTcYqyjList(tcYqyj);
        ExcelUtil<TcYqyj> util = new ExcelUtil<TcYqyj>(TcYqyj.class);
        util.exportExcel(response, list, "舆情预警数据");
    }

    /**
     * 获取舆情预警详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqyj:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcYqyjService.selectTcYqyjById(id));
    }

    /**
     * 新增舆情预警
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqyj:add')")
    @Log(title = "舆情预警", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcYqyj tcYqyj)
    {
        return toAjax(tcYqyjService.insertTcYqyj(tcYqyj));
    }

    /**
     * 修改舆情预警
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqyj:edit')")
    @Log(title = "舆情预警", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcYqyj tcYqyj)
    {
        return toAjax(tcYqyjService.updateTcYqyj(tcYqyj));
    }

    /**
     * 删除舆情预警
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netWorkYq:yqyj:remove')")
    @Log(title = "舆情预警", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcYqyjService.deleteTcYqyjByIds(ids));
    }
}
