package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcYtlc;
import com.ruoyi.tcZz.service.ITcYtlcService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 约谈流程Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@RequestMapping("/tcZz/netManage/ytlc")
public class TcYtlcController extends BaseController
{
    @Autowired
    private ITcYtlcService tcYtlcService;

    /**
     * 查询约谈流程列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:ytlc:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcYtlc tcYtlc)
    {
        startPage();
        List<TcYtlc> list = tcYtlcService.selectTcYtlcList(tcYtlc);
        return getDataTable(list);
    }

    /**
     * 导出约谈流程列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:ytlc:export')")
    @Log(title = "约谈流程", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcYtlc tcYtlc)
    {
        List<TcYtlc> list = tcYtlcService.selectTcYtlcList(tcYtlc);
        ExcelUtil<TcYtlc> util = new ExcelUtil<TcYtlc>(TcYtlc.class);
        util.exportExcel(response, list, "约谈流程数据");
    }

    /**
     * 获取约谈流程详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:ytlc:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcYtlcService.selectTcYtlcById(id));
    }

    /**
     * 新增约谈流程
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:ytlc:add')")
    @Log(title = "约谈流程", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcYtlc tcYtlc)
    {
        return toAjax(tcYtlcService.insertTcYtlc(tcYtlc));
    }

    /**
     * 修改约谈流程
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:ytlc:edit')")
    @Log(title = "约谈流程", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcYtlc tcYtlc)
    {
        return toAjax(tcYtlcService.updateTcYtlc(tcYtlc));
    }

    /**
     * 删除约谈流程
     */
    @PreAuthorize("@ss.hasPermi('tcZz/netManage:ytlc:remove')")
    @Log(title = "约谈流程", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcYtlcService.deleteTcYtlcByIds(ids));
    }
}
