package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcZfwz;
import com.ruoyi.tcZz.service.ITcZfwzService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 政府网站Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/zfwz")
public class TcZfwzController extends BaseController
{
    @Autowired
    private ITcZfwzService tcZfwzService;

    /**
     * 查询政府网站列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:zfwz:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcZfwz tcZfwz)
    {
        startPage();
        List<TcZfwz> list = tcZfwzService.selectTcZfwzList(tcZfwz);
        return getDataTable(list);
    }

    /**
     * 导出政府网站列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:zfwz:export')")
    @Log(title = "政府网站", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZfwz tcZfwz)
    {
        List<TcZfwz> list = tcZfwzService.selectTcZfwzList(tcZfwz);
        ExcelUtil<TcZfwz> util = new ExcelUtil<TcZfwz>(TcZfwz.class);
        util.exportExcel(response, list, "政府网站数据");
    }

    /**
     * 获取政府网站详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:zfwz:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcZfwzService.selectTcZfwzById(id));
    }

    /**
     * 新增政府网站
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:zfwz:add')")
    @Log(title = "政府网站", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcZfwz tcZfwz)
    {
        return toAjax(tcZfwzService.insertTcZfwz(tcZfwz));
    }

    /**
     * 修改政府网站
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:zfwz:edit')")
    @Log(title = "政府网站", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcZfwz tcZfwz)
    {
        return toAjax(tcZfwzService.updateTcZfwz(tcZfwz));
    }

    /**
     * 删除政府网站
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:zfwz:remove')")
    @Log(title = "政府网站", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcZfwzService.deleteTcZfwzByIds(ids));
    }
}
